==> e107_0.7.23_full.tar.gz: e107_languages/English/admin/lan_credits.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_credits.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 12:56:14 -0600 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("PAGE_NAME", "e107 Credits");

define("CRELAN_1", "Credits");
define("CRELAN_2", "Here is a list of third-party software / resources used in e107. The e107 development team would like to personally thank the developers of the following for allowing us to redistribute their code with e107, and for releasing their software under the GPL licence.");
define("CRELAN_3", "all rights reserved");
define("CRELAN_4", "Show e107 Dev Team");
define("CRELAN_5", "Show third party scripts");
define("CRELAN_6", "e107 v0.7 was brought to you by ...");
define("CRELAN_7", "version");
define("CRELAN_8", "permission granted");
define("CRELAN_9", "Licence");

// third party scripts

define("CRELAN_10", "MagpieRSS provides an XML-based (expat) RSS parser in PHP.");
define("CRELAN_11", "PclZip library offers compression and extraction functions for Zip formatted archives (WinZip, PKZIP).");
define("CRELAN_12", "PclTar offer the ability to archive a list of files or directories with or without compression. The archives created by PclTar are readable by most of gzip/tar applications and by the Windows WinZip application.");
define("CRELAN_13", "TinyMCE is a platform independent web based Javascript HTML WYSIWYG editor control released as Open Source under LGPL by Moxiecode Systems AB. It has the ability to convert HTML TEXTAREA fields or other HTML elements to editor instances.");
define("CRELAN_14", "Icons used in e107");
define("CRELAN_15", "Full featured email transfer class for PHP");
define("CRELAN_16", "Menu system used in Jayya theme");
define("CRELAN_17", "Popup calendar widget");
define("CRELAN_18", "PDF support");
define("CRELAN_19", "UTF-8 PDF support");

// end third party scripts

// dev team

define("CRELAN_20", ""); // asperon
define("CRELAN_21", "Always a pressure..err..pleasure!"); // CaMer0n
define("CRELAN_22", "\"MTVhNjMyZDgxN2QwM2Q3ZTI<br />5ODM2NDU3YWI0ZjM1NGILJT<br />yarrrrrr! wtf matey!\""); // jalist
define("CRELAN_23", ""); // lisa
define("CRELAN_24", ""); // McFly
define("CRELAN_25", ""); // que
define("CRELAN_26", ""); // streaky
define("CRELAN_27", "\"Wot? No tea?? 0_0\""); // SweetAs
define("CRELAN_28", ""); // MrPete

// end dev team

?>

==> e107_0.7.24_full.tar.gz: e107_languages/English/admin/lan_credits.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_credits.php $
|     $Revision: 11678 $
|     $Id: lan_credits.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("PAGE_NAME", "e107 Credits");

define("CRELAN_1", "Credits");
define("CRELAN_2", "Here is a list of third-party software / resources used in e107. The e107 development team would like to personally thank the developers of the following for allowing us to redistribute their code with e107, and for releasing their software under the GPL licence.");
define("CRELAN_3", "all rights reserved");
define("CRELAN_4", "Show e107 Dev Team");
define("CRELAN_5", "Show third party scripts");
define("CRELAN_6", "e107 v0.7 was brought to you by ...");
define("CRELAN_7", "version");
define("CRELAN_8", "permission granted");
define("CRELAN_9", "Licence");

// third party scripts

define("CRELAN_10", "MagpieRSS provides an XML-based (expat) RSS parser in PHP.");
define("CRELAN_11", "PclZip library offers compression and extraction functions for Zip formatted archives (WinZip, PKZIP).");
define("CRELAN_12", "PclTar offer the ability to archive a list of files or directories with or without compression. The archives created by PclTar are readable by most of gzip/tar applications and by the Windows WinZip application.");
define("CRELAN_13", "TinyMCE is a platform independent web based Javascript HTML WYSIWYG editor control released as Open Source under LGPL by Moxiecode Systems AB. It has the ability to convert HTML TEXTAREA fields or other HTML elements to editor instances.");
define("CRELAN_14", "Icons used in e107");
define("CRELAN_15", "Full featured email transfer class for PHP");
define("CRELAN_16", "Menu system used in Jayya theme");
define("CRELAN_17", "Popup calendar widget");
define("CRELAN_18", "PDF support");
define("CRELAN_19", "UTF-8 PDF support");

// end third party scripts

// dev team

define("CRELAN_20", ""); // asperon
define("CRELAN_21", "Always a pressure..err..pleasure!"); // CaMer0n
define("CRELAN_22", "\"MTVhNjMyZDgxN2QwM2Q3ZTI<br />5ODM2NDU3YWI0ZjM1NGILJT<br />yarrrrrr! wtf matey!\""); // jalist
define("CRELAN_23", ""); // lisa
define("CRELAN_24", ""); // McFly
define("CRELAN_25", ""); // que
define("CRELAN_26", ""); // streaky
define("CRELAN_27", "\"Wot? No tea?? 0_0\""); // SweetAs
define("CRELAN_28", ""); // MrPete

// end dev team

?>
